@@ -2,18 +2,21 @@
 # TITLE                                                                #
 # Antimicrobial Resistance (AMR) Analysis                              #
 #                                                                      #
-# AUTHORS                                                              #
-# Berends MS (m.s.berends@umcg.nl), Luz CF (c.f.luz@umcg.nl)           #
+# SOURCE                                                               #
+# https://gitlab.com/msberends/AMR                                     #
 #                                                                      #
 # LICENCE                                                              #
-# This program is free software; you can redistribute it and/or modify #
-# it under the terms of the GNU General Public License version 2.0,    #
-# as published by the Free Software Foundation.                        #
+# (c) 2019 Berends MS (m.s.berends@umcg.nl), Luz CF (c.f.luz@umcg.nl)  #
 #                                                                      #
-# This program is distributed in the hope that it will be useful,      #
-# but WITHOUT ANY WARRANTY; without even the implied warranty of       #
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        #
-# GNU General Public License for more details.                         #
+# This R package is free software; you can freely use and distribute   #
+# it for both personal and commercial purposes under the terms of the  #
+# GNU General Public License version 2.0 (GNU GPL-2), as published by  #
+# the Free Software Foundation.                                        #
+#                                                                      #
+# This R package was created for academic research and was publicly    #
+# released in the hope that it will be useful, but it comes WITHOUT    #
+# ANY WARRANTY OR LIABILITY.                                           #
+# Visit our website for more info: https://msberends.gitab.io/AMR.     #
 # ==================================================================== #
 
 globalVariables(c(".",
@@ -21,61 +24,83 @@ globalVariables(c(".",
                   "antibiotic",
                   "Antibiotic",
                   "antibiotics",
+                  "atc",
                   "authors",
                   "Becker",
+                  "certe",
                   "cnt",
+                  "col_id",
                   "count",
                   "count.x",
                   "count.y",
                   "cum_count",
                   "cum_percent",
                   "date_lab",
-                  "days_diff",
                   "diff.percent",
                   "fctlvl",
+                  "First name",
                   "first_isolate_row_index",
                   "Freq",
                   "fullname",
+                  "fullname_lower",
                   "genus",
                   "gramstain",
                   "index",
                   "Interpretation",
+                  "input",
                   "item",
                   "key_ab",
                   "key_ab_lag",
                   "key_ab_other",
+                  "kingdom",
+                  "labs",
                   "Lancefield",
+                  "Last name",
                   "lbl",
                   "median",
                   "mic",
                   "microorganisms",
+                  "microorganisms.codes",
                   "microorganisms.old",
-                  "microorganismsDT",
+                  "microorganisms.oldDT",
                   "microorganisms.prevDT",
                   "microorganisms.unprevDT",
-                  "microorganisms.oldDT",
-                  "microorganisms.certe",
-                  "microorganisms.umcg",
+                  "microorganismsDT",
                   "mo",
                   "mo.old",
+                  "more_than_episode_ago",
                   "n",
                   "name",
                   "observations",
+                  "observed",
+                  "official",
                   "other_pat_or_mo",
                   "Pasted",
                   "patient_id",
+                  "phylum",
                   "prevalence",
+                  "prevalent",
+                  "property",
                   "psae",
                   "R",
-                  "ref",
                   "real_first_isolate",
+                  "ref",
                   "S",
+                  "se_max",
+                  "se_min",
                   "septic_patients",
+                  "Sex",
                   "shortname",
                   "species",
+                  "species_id",
+                  "subspecies",
+                  "trade_name",
+                  "transmute",
                   "tsn",
                   "tsn_new",
+                  "umcg",
                   "value",
                   "Value",
+                  "x",
                   "y",
                   "year"))
