@@ -2,18 +2,21 @@
 # TITLE                                                                #
 # Antimicrobial Resistance (AMR) Analysis                              #
 #                                                                      #
-# AUTHORS                                                              #
-# Berends MS (m.s.berends@umcg.nl), Luz CF (c.f.luz@umcg.nl)           #
+# SOURCE                                                               #
+# https://gitlab.com/msberends/AMR                                     #
 #                                                                      #
 # LICENCE                                                              #
-# This program is free software; you can redistribute it and/or modify #
-# it under the terms of the GNU General Public License version 2.0,    #
-# as published by the Free Software Foundation.                        #
+# (c) 2019 Berends MS (m.s.berends@umcg.nl), Luz CF (c.f.luz@umcg.nl)  #
 #                                                                      #
-# This program is distributed in the hope that it will be useful,      #
-# but WITHOUT ANY WARRANTY; without even the implied warranty of       #
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        #
-# GNU General Public License for more details.                         #
+# This R package is free software; you can freely use and distribute   #
+# it for both personal and commercial purposes under the terms of the  #
+# GNU General Public License version 2.0 (GNU GPL-2), as published by  #
+# the Free Software Foundation.                                        #
+#                                                                      #
+# This R package was created for academic research and was publicly    #
+# released in the hope that it will be useful, but it comes WITHOUT    #
+# ANY WARRANTY OR LIABILITY.                                           #
+# Visit our website for more info: https://msberends.gitab.io/AMR.     #
 # ==================================================================== #
 
 #' Determine multidrug-resistant organisms (MDRO)
@@ -23,15 +26,16 @@
 #' @param country country code to determine guidelines. EUCAST rules will be used when left empty, see Details. Should be or a code from the \href{https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2#Officially_assigned_code_elements}{list of ISO 3166-1 alpha-2 country codes}. Case-insensitive. Currently supported are \code{de} (Germany) and \code{nl} (the Netherlands).
 #' @param info print progress
 #' @inheritParams eucast_rules
-#' @param metr column name of an antibiotic. Use \code{NA} to skip a column, like \code{tica = NA}. Non-existing columns will anyway be skipped. See the Antibiotics section for an explanation of the abbreviations.
+#' @param metr column name of an antibiotic, see Antibiotics
 #' @param ... parameters that are passed on to methods
 #' @inheritSection eucast_rules Antibiotics
 #' @details When \code{country} will be left blank, guidelines will be taken from EUCAST Expert Rules Version 3.1 "Intrinsic Resistance and Exceptional Phenotypes Tables" (\url{http://www.eucast.org/fileadmin/src/media/PDFs/EUCAST_files/Expert_Rules/Expert_rules_intrinsic_exceptional_V3.1.pdf}).
 #' @return Ordered factor with levels \code{Negative < Positive, unconfirmed < Positive}.
 #' @rdname mdro
 #' @importFrom dplyr %>%
-#' @importFrom crayon red blue
+#' @importFrom crayon red blue bold
 #' @export
+#' @inheritSection AMR Read more on our website!
 #' @examples
 #' library(dplyr)
 #'
@@ -42,67 +46,66 @@ mdro <- function(tbl,
                  country = NULL,
                  col_mo = NULL,
                  info = TRUE,
-                 amcl = 'amcl',
-                 amik = 'amik',
-                 amox = 'amox',
-                 ampi = 'ampi',
-                 azit = 'azit',
-                 aztr = 'aztr',
-                 cefa = 'cefa',
-                 cfra = 'cfra',
-                 cfep = 'cfep',
-                 cfot = 'cfot',
-                 cfox = 'cfox',
-                 cfta = 'cfta',
-                 cftr = 'cftr',
-                 cfur = 'cfur',
-                 chlo = 'chlo',
-                 cipr = 'cipr',
-                 clar = 'clar',
-                 clin = 'clin',
-                 clox = 'clox',
-                 coli = 'coli',
-                 czol = 'czol',
-                 dapt = 'dapt',
-                 doxy = 'doxy',
-                 erta = 'erta',
-                 eryt = 'eryt',
-                 fosf = 'fosf',
-                 fusi = 'fusi',
-                 gent = 'gent',
-                 imip = 'imip',
-                 kana = 'kana',
-                 levo = 'levo',
-                 linc = 'linc',
-                 line = 'line',
-                 mero = 'mero',
-                 metr = 'metr',
-                 mino = 'mino',
-                 moxi = 'moxi',
-                 nali = 'nali',
-                 neom = 'neom',
-                 neti = 'neti',
-                 nitr = 'nitr',
-                 novo = 'novo',
-                 norf = 'norf',
-                 oflo = 'oflo',
-                 peni = 'peni',
-                 pipe = 'pipe',
-                 pita = 'pita',
-                 poly = 'poly',
-                 qida = 'qida',
-                 rifa = 'rifa',
-                 roxi = 'roxi',
-                 siso = 'siso',
-                 teic = 'teic',
-                 tetr = 'tetr',
-                 tica = 'tica',
-                 tige = 'tige',
-                 tobr = 'tobr',
-                 trim = 'trim',
-                 trsu = 'trsu',
-                 vanc = 'vanc',
-                 col_bactid = NULL) {
+                 amcl = guess_ab_col(),
+                 amik = guess_ab_col(),
+                 amox = guess_ab_col(),
+                 ampi = guess_ab_col(),
+                 azit = guess_ab_col(),
+                 aztr = guess_ab_col(),
+                 cefa = guess_ab_col(),
+                 cfra = guess_ab_col(),
+                 cfep = guess_ab_col(),
+                 cfot = guess_ab_col(),
+                 cfox = guess_ab_col(),
+                 cfta = guess_ab_col(),
+                 cftr = guess_ab_col(),
+                 cfur = guess_ab_col(),
+                 chlo = guess_ab_col(),
+                 cipr = guess_ab_col(),
+                 clar = guess_ab_col(),
+                 clin = guess_ab_col(),
+                 clox = guess_ab_col(),
+                 coli = guess_ab_col(),
+                 czol = guess_ab_col(),
+                 dapt = guess_ab_col(),
+                 doxy = guess_ab_col(),
+                 erta = guess_ab_col(),
+                 eryt = guess_ab_col(),
+                 fosf = guess_ab_col(),
+                 fusi = guess_ab_col(),
+                 gent = guess_ab_col(),
+                 imip = guess_ab_col(),
+                 kana = guess_ab_col(),
+                 levo = guess_ab_col(),
+                 linc = guess_ab_col(),
+                 line = guess_ab_col(),
+                 mero = guess_ab_col(),
+                 metr = guess_ab_col(),
+                 mino = guess_ab_col(),
+                 moxi = guess_ab_col(),
+                 nali = guess_ab_col(),
+                 neom = guess_ab_col(),
+                 neti = guess_ab_col(),
+                 nitr = guess_ab_col(),
+                 novo = guess_ab_col(),
+                 norf = guess_ab_col(),
+                 oflo = guess_ab_col(),
+                 peni = guess_ab_col(),
+                 pipe = guess_ab_col(),
+                 pita = guess_ab_col(),
+                 poly = guess_ab_col(),
+                 qida = guess_ab_col(),
+                 rifa = guess_ab_col(),
+                 roxi = guess_ab_col(),
+                 siso = guess_ab_col(),
+                 teic = guess_ab_col(),
+                 tetr = guess_ab_col(),
+                 tica = guess_ab_col(),
+                 tige = guess_ab_col(),
+                 tobr = guess_ab_col(),
+                 trim = guess_ab_col(),
+                 trsu = guess_ab_col(),
+                 vanc = guess_ab_col()) {
 
   if (!is.data.frame(tbl)) {
     stop("`tbl` must be a data frame.", call. = FALSE)
@@ -110,14 +113,11 @@ mdro <- function(tbl,
 
   # try to find columns based on type
   # -- mo
-  if (!is.null(col_bactid)) {
-    col_mo <- col_bactid
-    warning("Use of `col_bactid` is deprecated. Use `col_mo` instead.")
-  } else if (is.null(col_mo) & "mo" %in% lapply(tbl, class)) {
-    col_mo <- colnames(tbl)[lapply(tbl, class) == "mo"][1]
-    message("NOTE: Using column `", col_mo, "` as input for `col_mo`.")
-  } else if (!col_mo %in% colnames(tbl)) {
-    stop('Column ', col_mo, ' not found.', call. = FALSE)
+  if (is.null(col_mo)) {
+    col_mo <- search_type_in_df(tbl = tbl, type = "mo")
+  }
+  if (is.null(col_mo)) {
+    stop("`col_mo` must be set.", call. = FALSE)
   }
 
   # strip whitespaces
@@ -150,7 +150,7 @@ mdro <- function(tbl,
   } else if (guideline$country$code == 'nl') {
     guideline$country$name <- 'The Netherlands'
     guideline$name <- 'WIP-Richtlijn BRMO'
-    guideline$version <- 'Revision of December 2017'
+    guideline$version <- 'Revision as of December 2017'
     guideline$source <- 'https://www.rivm.nl/Documenten_en_publicaties/Professioneel_Praktisch/Richtlijnen/Infectieziekten/WIP_Richtlijnen/WIP_Richtlijnen/Ziekenhuizen/WIP_richtlijn_BRMO_Bijzonder_Resistente_Micro_Organismen_ZKH'
     # add here more countries like this:
     # } else if (country$code == 'xx') {
@@ -168,12 +168,77 @@ mdro <- function(tbl,
   }
 
   # check columns
+  if (identical(amcl, as.name("guess_ab_col"))) { amcl <- guess_ab_col(tbl, "amcl", verbose = info) }
+  if (identical(amik, as.name("guess_ab_col"))) { amik <- guess_ab_col(tbl, "amik", verbose = info) }
+  if (identical(amox, as.name("guess_ab_col"))) { amox <- guess_ab_col(tbl, "amox", verbose = info) }
+  if (identical(ampi, as.name("guess_ab_col"))) { ampi <- guess_ab_col(tbl, "ampi", verbose = info) }
+  if (identical(azit, as.name("guess_ab_col"))) { azit <- guess_ab_col(tbl, "azit", verbose = info) }
+  if (identical(aztr, as.name("guess_ab_col"))) { aztr <- guess_ab_col(tbl, "aztr", verbose = info) }
+  if (identical(cefa, as.name("guess_ab_col"))) { cefa <- guess_ab_col(tbl, "cefa", verbose = info) }
+  if (identical(cfra, as.name("guess_ab_col"))) { cfra <- guess_ab_col(tbl, "cfra", verbose = info) }
+  if (identical(cfep, as.name("guess_ab_col"))) { cfep <- guess_ab_col(tbl, "cfep", verbose = info) }
+  if (identical(cfot, as.name("guess_ab_col"))) { cfot <- guess_ab_col(tbl, "cfot", verbose = info) }
+  if (identical(cfox, as.name("guess_ab_col"))) { cfox <- guess_ab_col(tbl, "cfox", verbose = info) }
+  if (identical(cfta, as.name("guess_ab_col"))) { cfta <- guess_ab_col(tbl, "cfta", verbose = info) }
+  if (identical(cftr, as.name("guess_ab_col"))) { cftr <- guess_ab_col(tbl, "cftr", verbose = info) }
+  if (identical(cfur, as.name("guess_ab_col"))) { cfur <- guess_ab_col(tbl, "cfur", verbose = info) }
+  if (identical(chlo, as.name("guess_ab_col"))) { chlo <- guess_ab_col(tbl, "chlo", verbose = info) }
+  if (identical(cipr, as.name("guess_ab_col"))) { cipr <- guess_ab_col(tbl, "cipr", verbose = info) }
+  if (identical(clar, as.name("guess_ab_col"))) { clar <- guess_ab_col(tbl, "clar", verbose = info) }
+  if (identical(clin, as.name("guess_ab_col"))) { clin <- guess_ab_col(tbl, "clin", verbose = info) }
+  if (identical(clox, as.name("guess_ab_col"))) { clox <- guess_ab_col(tbl, "clox", verbose = info) }
+  if (identical(coli, as.name("guess_ab_col"))) { coli <- guess_ab_col(tbl, "coli", verbose = info) }
+  if (identical(czol, as.name("guess_ab_col"))) { czol <- guess_ab_col(tbl, "czol", verbose = info) }
+  if (identical(dapt, as.name("guess_ab_col"))) { dapt <- guess_ab_col(tbl, "dapt", verbose = info) }
+  if (identical(doxy, as.name("guess_ab_col"))) { doxy <- guess_ab_col(tbl, "doxy", verbose = info) }
+  if (identical(erta, as.name("guess_ab_col"))) { erta <- guess_ab_col(tbl, "erta", verbose = info) }
+  if (identical(eryt, as.name("guess_ab_col"))) { eryt <- guess_ab_col(tbl, "eryt", verbose = info) }
+  if (identical(fosf, as.name("guess_ab_col"))) { fosf <- guess_ab_col(tbl, "fosf", verbose = info) }
+  if (identical(fusi, as.name("guess_ab_col"))) { fusi <- guess_ab_col(tbl, "fusi", verbose = info) }
+  if (identical(gent, as.name("guess_ab_col"))) { gent <- guess_ab_col(tbl, "gent", verbose = info) }
+  if (identical(imip, as.name("guess_ab_col"))) { imip <- guess_ab_col(tbl, "imip", verbose = info) }
+  if (identical(kana, as.name("guess_ab_col"))) { kana <- guess_ab_col(tbl, "kana", verbose = info) }
+  if (identical(levo, as.name("guess_ab_col"))) { levo <- guess_ab_col(tbl, "levo", verbose = info) }
+  if (identical(linc, as.name("guess_ab_col"))) { linc <- guess_ab_col(tbl, "linc", verbose = info) }
+  if (identical(line, as.name("guess_ab_col"))) { line <- guess_ab_col(tbl, "line", verbose = info) }
+  if (identical(mero, as.name("guess_ab_col"))) { mero <- guess_ab_col(tbl, "mero", verbose = info) }
+  if (identical(metr, as.name("guess_ab_col"))) { metr <- guess_ab_col(tbl, "metr", verbose = info) }
+  if (identical(mino, as.name("guess_ab_col"))) { mino <- guess_ab_col(tbl, "mino", verbose = info) }
+  if (identical(moxi, as.name("guess_ab_col"))) { moxi <- guess_ab_col(tbl, "moxi", verbose = info) }
+  if (identical(nali, as.name("guess_ab_col"))) { nali <- guess_ab_col(tbl, "nali", verbose = info) }
+  if (identical(neom, as.name("guess_ab_col"))) { neom <- guess_ab_col(tbl, "neom", verbose = info) }
+  if (identical(neti, as.name("guess_ab_col"))) { neti <- guess_ab_col(tbl, "neti", verbose = info) }
+  if (identical(nitr, as.name("guess_ab_col"))) { nitr <- guess_ab_col(tbl, "nitr", verbose = info) }
+  if (identical(novo, as.name("guess_ab_col"))) { novo <- guess_ab_col(tbl, "novo", verbose = info) }
+  if (identical(norf, as.name("guess_ab_col"))) { norf <- guess_ab_col(tbl, "norf", verbose = info) }
+  if (identical(oflo, as.name("guess_ab_col"))) { oflo <- guess_ab_col(tbl, "oflo", verbose = info) }
+  if (identical(peni, as.name("guess_ab_col"))) { peni <- guess_ab_col(tbl, "peni", verbose = info) }
+  if (identical(pipe, as.name("guess_ab_col"))) { pipe <- guess_ab_col(tbl, "pipe", verbose = info) }
+  if (identical(pita, as.name("guess_ab_col"))) { pita <- guess_ab_col(tbl, "pita", verbose = info) }
+  if (identical(poly, as.name("guess_ab_col"))) { poly <- guess_ab_col(tbl, "poly", verbose = info) }
+  if (identical(qida, as.name("guess_ab_col"))) { qida <- guess_ab_col(tbl, "qida", verbose = info) }
+  if (identical(rifa, as.name("guess_ab_col"))) { rifa <- guess_ab_col(tbl, "rifa", verbose = info) }
+  if (identical(roxi, as.name("guess_ab_col"))) { roxi <- guess_ab_col(tbl, "roxi", verbose = info) }
+  if (identical(siso, as.name("guess_ab_col"))) { siso <- guess_ab_col(tbl, "siso", verbose = info) }
+  if (identical(teic, as.name("guess_ab_col"))) { teic <- guess_ab_col(tbl, "teic", verbose = info) }
+  if (identical(tetr, as.name("guess_ab_col"))) { tetr <- guess_ab_col(tbl, "tetr", verbose = info) }
+  if (identical(tica, as.name("guess_ab_col"))) { tica <- guess_ab_col(tbl, "tica", verbose = info) }
+  if (identical(tige, as.name("guess_ab_col"))) { tige <- guess_ab_col(tbl, "tige", verbose = info) }
+  if (identical(tobr, as.name("guess_ab_col"))) { tobr <- guess_ab_col(tbl, "tobr", verbose = info) }
+  if (identical(trim, as.name("guess_ab_col"))) { trim <- guess_ab_col(tbl, "trim", verbose = info) }
+  if (identical(trsu, as.name("guess_ab_col"))) { trsu <- guess_ab_col(tbl, "trsu", verbose = info) }
+  if (identical(vanc, as.name("guess_ab_col"))) { vanc <- guess_ab_col(tbl, "vanc", verbose = info) }
   col.list <- c(amcl, amik, amox, ampi, azit, aztr, cefa, cfra, cfep, cfot,
                 cfox, cfta, cftr, cfur, chlo, cipr, clar, clin, clox, coli,
                 czol, dapt, doxy, erta, eryt, fosf, fusi, gent, imip, kana,
-                levo, linc, line, mero, metr, mino, moxi, nali, neom, neti, nitr,
-                novo, norf, oflo, peni, pita, poly, qida, rifa, roxi, siso,
-                teic, tetr, tica, tige, tobr, trim, trsu, vanc)
+                levo, linc, line, mero, metr, mino, moxi, nali, neom, neti,
+                nitr, novo, norf, oflo, peni, pipe, pita, poly, qida, rifa,
+                roxi, siso, teic, tetr, tica, tige, tobr, trim, trsu, vanc)
+  if (length(col.list) < 60) {
+    warning('Some columns do not exist -- THIS MAY STRONGLY INFLUENCE THE OUTCOME.',
+            immediate. = TRUE,
+            call. = FALSE)
+  }
   col.list <- check_available_columns(tbl = tbl, col.list = col.list, info = info)
   amcl <- col.list[amcl]
   amik <- col.list[amik]
@@ -220,6 +285,7 @@ mdro <- function(tbl,
   norf <- col.list[norf]
   oflo <- col.list[oflo]
   peni <- col.list[peni]
+  pipe <- col.list[pipe]
   pita <- col.list[pita]
   poly <- col.list[poly]
   qida <- col.list[qida]
@@ -259,11 +325,8 @@ mdro <- function(tbl,
     }
   }
 
-  if (!tbl %>% pull(col_mo) %>% is.mo()) {
-    tbl[, col_mo] <- as.mo(tbl[, col_mo])
-  }
-
   tbl <- tbl %>%
+    mutate_at(vars(col_mo), as.mo) %>%
     # join to microorganisms data set
     left_join_microorganisms(by = col_mo) %>%
     # add unconfirmed to where genus is available
